************
* SCRIPT: 3_figures.do
* PURPOSE: creates the EPS figures for the paper
************

************
* Code begins
************

*** Experiment 1

use "$ExtremeToMainstream_Replication/processed/exp1_clean.dta", clear




* Figure 1

reg donate clinton_private clinton_public trump_private trump_public, nocons r

foreach i in clinton_private clinton_public trump_private trump_public {
local perc_`i' = string(round(_b[`i']*100,1),"%9.0f") + "%"
}

test _b[clinton_private]=_b[clinton_public]
if round(r(p),.0001) > 0.001 local p_cliton_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_cliton_pv_vs_pb = "p<0.001"
test _b[trump_private]=_b[trump_public]
if round(r(p),.0001) > 0.001 local p_trump_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_trump_pv_vs_pb = "p<0.001"
test _b[clinton_public] = _b[trump_public]
if round(r(p),.0001) > 0.001 local p_public_cl_vs_tr = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_public_cl_vs_tr = "p<0.001"
test _b[clinton_private] = _b[trump_private]
if round(r(p),.0001) > 0.001 local p_private_cl_vs_tr = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_private_cl_vs_tr = "p<0.001"

display _N
preserve
keep donate treatment
replace donate = donate * 100
collapse (mean) meandonate = donate (sd) sddonate=donate (count) n=donate, by(treatment)
generate hidonate = meandonate + 1.96*(sddonate/sqrt(n))
generate lodonate = meandonate - 1.96*(sddonate/sqrt(n))
generate order = 1 if treatment == "Clinton Won Private"
replace order = 2 if treatment == "Clinton Won Public"
replace order = 4 if treatment == "Trump Won Private"
replace order = 5 if treatment == "Trump Won Public"
twoway (bar meandonate order if (treatment == "Clinton Won Private" | treatment == "Trump Won Private"), barw(0.8) fc(white) lc(black) lw(medium)) ///
       (bar meandonate order if (treatment == "Clinton Won Public" | treatment == "Trump Won Public"), barw(0.8) fc(maroon) fi(inten50) lc(black) lw(medium)) ///
       (pci 41 1 41 1.2  40.2 1 41.05 1  41 2 41 1.8  40.2 2 41.05 2, lc(black)) ///
       (pci 41 4 41 4.2  40.2 4 41.05 4  41 5 41 4.8  40.2 5 41.05 5, lc(black)) ///
       (pci 39 2 39 3.2  38.2 2 39.05 2  39 5 39 3.8  38.2 5 39.05 5, lc(black)) ///
       (pci 37 1 37 2.2  36.2 1 37.05 1  37 4 37 2.8  36.2 4 37.05 4, lc(black)) ///
       (rcap hidonate lodonate order, lc(black)), ///
       graphregion(color(white)) ///
       legend(row(2) order(1 "Private" 2 "Public") region(lstyle(none)) ring(0) symxsize(4)) ///
       ylabel(0(5)40, nogrid) yscale(range(0 41)) ///
       xlabel(1.5 "Clinton Won Treatment" 4.5 "Trump Won Treatment", noticks) xtick(3(3)3) ///
       text(41 1.5 "`p_cliton_pv_vs_pb'") text(41 4.5 "`p_trump_pv_vs_pb'") text(39 3.5 "`p_public_cl_vs_tr'") text(37 2.5 "`p_private_cl_vs_tr'") ///
       text(10 1 "`perc_clinton_private'") text(10 2 "`perc_clinton_public'") text(10 4 "`perc_trump_private'") text(10 5 "`perc_trump_public'") ///
       xtitle("") ytitle("Donation Rates")
gr_edit legend.DragBy 10 0
graph export "$ExtremeToMainstream_Replication/results/figures/figure1.eps", replace
restore




* Figure 2

ttest sob_culture, by(trump)
if round(r(p),.0001) > 0.001 local p_ttest = "t test p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_ttest = "t test p<0.001"
local clinton = r(mu_1)
local trump = r(mu_2)

ksmirnov sob_culture, by(trump)
if round(r(p),.0001) > 0.001 local p_kstest = "K-S test p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_kstest = "K-S test p<0.001"

preserve
bysort trump: cumul sob_culture, gen(cdf_sob_culture)
bysort trump sob_culture: keep if _n == 1
twoway (connected cdf_sob_culture sob_culture if trump == 0, m(i) sort connect(J) lpattern(solid) lc(maroon)) ///
       (connected cdf_sob_culture sob_culture if trump == 1, m(i) sort connect(J) lpattern(dash) lc(navy)), /// 
graphregion(color(white)) ///
legend(row(2) order(1 "Clinton Won Treatment" 2 "Trump Won Treatment") region(lstyle(none)) ring(0) symxsize(4)) ///
xtitle("Perceived Popularity of Anti-Immigrant Sentiments") ytitle("Cumulative Distribution") ///
ylabel(0(.20)1,nogrid) ///
xline(`clinton', lc(maroon)) xline(`trump', lp(dash) lc(navy)) ///
text(.9 20 "`p_ttest'") text(.8 20 "`p_kstest'") 
gr_edit legend.DragBy 20 40
graph export "$ExtremeToMainstream_Replication/results/figures/figure2.eps", replace
restore





*** Experiment 2

use "$ExtremeToMainstream_Replication/processed/exp2_clean.dta", clear

* Figure 3 Panel A

reg donation_amount clinton_private clinton_public trump_private trump_public, nocons r

foreach i in clinton_private clinton_public trump_private trump_public {
local dollar_`i' = "$" + string(round(_b[`i'],0.01),"%9.2f")
}

test _b[clinton_private]=_b[clinton_public]
if round(r(p),.0001) > 0.001 local p_cliton_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_cliton_pv_vs_pb = "p<0.001"
test _b[trump_private]=_b[trump_public]
if round(r(p),.0001) > 0.001 local p_trump_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_trump_pv_vs_pb = "p<0.001"
test _b[clinton_public] = _b[trump_public]
if round(r(p),.0001) > 0.001 local p_public_cl_vs_tr = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_public_cl_vs_tr = "p<0.001"
test _b[clinton_private]=_b[trump_public]
if round(r(p),.0001) > 0.001 local p_cl_private_vs_tr_public = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_cl_private_vs_tr_public = "p<0.001"
test _b[clinton_private] = _b[trump_private] = _b[clinton_public]
if round(r(p),.0001) > 0.001 local p_three = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_three = "p<0.001"

preserve
keep donation_amount treatment
collapse (mean) meandonate = donation_amount (sd) sddonate=donation_amount (count) n=donation_amount, by(treatment)
generate hidonate = meandonate + 1.96*(sddonate/sqrt(n))
generate lodonate = meandonate - 1.96*(sddonate/sqrt(n))
generate order = 1 if treatment == "Clinton Won Private"
replace order = 2 if treatment == "Clinton Won Public"
replace order = 4 if treatment == "Trump Won Private"
replace order = 5 if treatment == "Trump Won Public"
twoway (bar meandonate order if (treatment == "Clinton Won Private" | treatment == "Trump Won Private"), barw(0.8) fc(white) lc(black) lw(medium)) ///
       (bar meandonate order if (treatment == "Clinton Won Public" | treatment == "Trump Won Public"), barw(0.8) fc(maroon) fi(inten50) lc(black) lw(medium)) ///
       (pci 0.92 1 0.92 2.2  0.905 1 0.921 1  0.92 4 0.92 2.8  0.905 4 0.921 4 0.905 2 0.921 2, lc(black)) ///
       (pci 0.96 1 0.96 2.7  0.945 1 0.961 1  0.96 5 0.96 3.3  0.945 5 0.961 5, lc(black)) ///
       (pci 1.00 2 1.00 3.2  0.985 2 1.001 2  1.00 5 1.00 3.8  0.985 5 1.001 5, lc(black)) ///
       (pci 1.04 4 1.04 4.2  1.025 4 1.041 4  1.04 5 1.04 4.8  1.025 5 1.041 5, lc(black)) ///
       (pci 1.04 1 1.04 1.2  1.025 1 1.041 1  1.04 2 1.04 1.8  1.025 2 1.041 2, lc(black)) ///
       (rcap hidonate lodonate order, lc(black)), ///
       graphregion(color(white)) ///
       legend(row(2) order(1 "Private" 2 "Public") region(lstyle(none)) ring(0) symxsize(4)) ///
       ylabel(0(0.1)1, nogrid) yscale(range(0 1.04)) ///
       xlabel(1.5 "Clinton Won Treatment" 4.5 "Trump Won Treatment", noticks) xtick(3(3)3) ///
       text(0.5 1 "`dollar_clinton_private'") text(0.5 2 "`dollar_clinton_public'") text(0.5 4 "`dollar_trump_private'") text(0.5 5 "`dollar_trump_public'") ///
       text(0.92 2.5 "`p_three'") text(0.96 3 "`p_cl_private_vs_tr_public'") text(1 3.5 "`p_public_cl_vs_tr'") text(1.04 4.5 "`p_trump_pv_vs_pb'")  text(1.04 1.5 "`p_cliton_pv_vs_pb'") ///
       xtitle("") ytitle("Average Donation Amounts")
gr_edit legend.DragBy 10 0
graph export "$ExtremeToMainstream_Replication/results/figures/figure3_panelA.eps", replace
restore


* Figure 3 Panel B

reg no_donation clinton_private clinton_public trump_private trump_public, nocons r

foreach i in clinton_private clinton_public trump_private trump_public {
local perc_`i' = string(round(_b[`i']*100,1),"%9.0f") + "%"
}

test _b[clinton_private]=_b[clinton_public]
if round(r(p),.0001) > 0.001 local p_cliton_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_cliton_pv_vs_pb = "p<0.001"
test _b[trump_private]=_b[trump_public]
if round(r(p),.0001) > 0.001 local p_trump_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_trump_pv_vs_pb = "p<0.001"
test _b[clinton_public] = _b[trump_public]
if round(r(p),.0001) > 0.001 local p_public_cl_vs_tr = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_public_cl_vs_tr = "p<0.001"
test _b[clinton_private]=_b[trump_public]
if round(r(p),.0001) > 0.001 local p_cl_private_vs_tr_public = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_cl_private_vs_tr_public = "p<0.001"
test _b[clinton_private] = _b[trump_private] = _b[clinton_public]
if round(r(p),.0001) > 0.001 local p_three = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_three = "p<0.001"

display _N
preserve
keep no_donation treatment
collapse (mean) meandonate = no_donation (sd) sddonate=no_donation (count) n=no_donation, by(treatment)
generate hidonate = meandonate + 1.96*(sddonate/sqrt(n))
generate lodonate = meandonate - 1.96*(sddonate/sqrt(n))
generate order = 1 if treatment == "Clinton Won Private"
replace order = 2 if treatment == "Clinton Won Public"
replace order = 4 if treatment == "Trump Won Private"
replace order = 5 if treatment == "Trump Won Public"
twoway (bar meandonate order if (treatment == "Clinton Won Private" | treatment == "Trump Won Private"), barw(0.8) fc(white) lc(black) lw(medium)) ///
       (bar meandonate order if (treatment == "Clinton Won Public" | treatment == "Trump Won Public"), barw(0.8) fc(maroon) fi(inten50) lc(black) lw(medium)) ///
       (pci 0.265 1 0.265 2.2  0.261 1 0.2653 1  0.265 4 0.265 2.8  0.261 4 0.2653 4 0.261 2 0.2653 2, lc(black)) ///
       (pci 0.275 1 0.275 2.7  0.271 1 0.2753 1  0.275 5 0.275 3.3  0.271 5 0.2753 5, lc(black)) ///
       (pci 0.285 2 0.285 3.2  0.281 2 0.2853 2  0.285 5 0.285 3.8  0.281 5 0.2853 5, lc(black)) ///
       (pci 0.295 4 0.295 4.2  0.291 4 0.2953 4  0.295 5 0.295 4.8  0.291 5 0.2953 5, lc(black)) ///
       (pci 0.295 1 0.295 1.2  0.291 1 0.2953 1  0.295 2 0.295 1.8  0.291 2 0.2953 2, lc(black)) ///
       (rcap hidonate lodonate order, lc(black)), ///
       graphregion(color(white)) ///
       legend(row(2) order(1 "Private" 2 "Public") region(lstyle(none)) ring(0) symxsize(4)) ///
       ylabel(0(0.05)0.3, nogrid) yscale(range(0 0.3)) ///
       xlabel(1.5 "Clinton Won Treatment" 4.5 "Trump Won Treatment", noticks) xtick(3(3)3) ///
       text(0.04 1 "`perc_clinton_private'") text(0.04 2 "`perc_clinton_public'") text(0.04 4 "`perc_trump_private'") text(0.04 5 "`perc_trump_public'") ///
       text(0.265 2.5 "`p_three'") text(0.275 3 "`p_cl_private_vs_tr_public'") text(0.285 3.5 "`p_public_cl_vs_tr'") text(0.295 4.5 "`p_trump_pv_vs_pb'") text(0.295 1.5 "`p_cliton_pv_vs_pb'") ///
       xtitle("") ytitle("Share Not Donating")
gr_edit legend.DragBy 10 0
graph export "$ExtremeToMainstream_Replication/results/figures/figure3_panelB.eps", replace
restore


* Figure 4

ttest sob_culture, by(trump)
if round(r(p),.0001) > 0.001 local p_ttest = "t test p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_ttest = "t test p<0.001"
local clinton = r(mu_1)
local trump = r(mu_2)
ksmirnov sob_culture, by(trump)
if round(r(p),.0001) > 0.001 local p_kstest = "K-S test p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_kstest = "K-S test p<0.001"

preserve
bysort trump: cumul sob_culture, gen(cdf_sob_culture)
bysort trump sob_culture: keep if _n == 1
twoway (connected cdf_sob_culture sob_culture if trump == 0, m(i) sort connect(J) lpattern(solid) lc(maroon)) ///
       (connected cdf_sob_culture sob_culture if trump == 1, m(i) sort connect(J) lpattern(dash) lc(navy)), /// 
graphregion(color(white)) ///
legend(row(2) order(1 "Clinton Won Treatment" 2 "Trump Won Treatment") region(lstyle(none)) ring(0) symxsize(4)) ///
xtitle("Perceived Popularity of Anti-Immigrant Sentiments") ytitle("Cumulative Distribution") ///
ylabel(0(.20)1,nogrid) ///
xline(`clinton', lc(maroon)) xline(`trump', lp(dash) lc(navy)) ///
text(.9 20 "`p_ttest'") text(.8 20 "`p_kstest'") 
gr_edit legend.DragBy 20 40
graph export "$ExtremeToMainstream_Replication/results/figures/figure4.eps", replace
restore




*** Appendix Experiment 1B

use "$ExtremeToMainstream_Replication/processed/app_exp1b_clean.dta", clear

* Appendix Figure D1

reg donate control_private control_public info_private info_public wave2_private wave2_public if (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1)), nocons r

foreach i in control_private control_public info_private info_public wave2_private wave2_public {
local perc_`i' = string(round(_b[`i']*100,1),"%9.0f") + "%"
}

test _b[control_private]=_b[control_public]
if round(r(p),.0001) > 0.001 local p_control_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_control_pv_vs_pb = "p<0.001"
test _b[info_private]=_b[info_public]
if round(r(p),.0001) > 0.001 local p_info_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_info_pv_vs_pb = "p<0.001"
test _b[wave2_private]=_b[wave2_public]
if round(r(p),.0001) > 0.001 local p_wave2_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_wave2_pv_vs_pb = "p<0.001"
test _b[control_public] = _b[info_public]
if round(r(p),.0001) > 0.001 local p_public_ctrl_vs_info = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_public_ctrl_vs_info = "p<0.001"
test _b[control_public] = _b[wave2_public]
if round(r(p),.0001) > 0.001 local p_public_ctrl_vs_wave2 = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_public_ctrl_vs_wave2 = "p<0.001"

display _N
preserve
keep if (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1))
keep donate group
replace donate = donate * 100
collapse (mean) meandonate = donate (sd) sddonate=donate (count) n=donate, by(group)
generate hidonate = meandonate + 1.96*(sddonate/sqrt(n))
generate lodonate = meandonate - 1.96*(sddonate/sqrt(n))
generate order = 1 if group == "Control Private"
replace order = 2 if group == "Control Public"
replace order = 4 if group == "Information Private"
replace order = 5 if group == "Information Public"
replace order = 7 if group == "Control Private Wave 2"
replace order = 8 if group == "Control Public Wave 2"
twoway (bar meandonate order if (group == "Control Private" | group == "Information Private" | group == "Control Private Wave 2"), barw(0.8) fc(white) lc(black) lw(medium)) ///
       (bar meandonate order if (group == "Control Public" | group == "Information Public" | group == "Control Public Wave 2"), barw(0.8) fc(maroon) fi(inten50) lc(black) lw(medium)) ///
       (pci 72.5 1 72.5 1.05  71 1 72.65 1  72.5 2 72.5 1.95  71 2 72.65 2, lc(black)) ///
       (pci 72.5 4 72.5 4.05  71 4 72.65 4  72.5 5 72.5 4.95  71 5 72.65 5, lc(black)) ///
       (pci 72.5 7 72.5 7.05  71 7 72.65 7  72.5 8 72.5 7.95  71 8 72.65 8, lc(black)) ///
       (pci 59 2 59 3.05  58 2 59.15 2  59 5 59 3.95  58 5 59.15 5, lc(black)) ///
       (pci 65 2 65 4.525  63.5 2 65 2  65 8 65 5.45  63.5 8 65 8, lc(black)) ///
       (rcap hidonate lodonate order, lc(black)), ///
       graphregion(color(white)) ///
       legend(row(2) order(1 "Private" 2 "Public") region(lstyle(none)) ring(0) symxsize(4)) ///
       ylabel(0(10)70, nogrid) yscale(range(0 72.5)) ///
       xlabel( 1.5 "Control Before Election" 4.5 "Information Before Election" 7.5 "Control After Election", noticks) xtick(3(3)6) ///
       text(72.5 1.5 "`p_control_pv_vs_pb'") text(72.5 4.5 "`p_info_pv_vs_pb'") text(72.5 7.5 "`p_wave2_pv_vs_pb'") text(59 3.5 "`p_public_ctrl_vs_info'")  text(65 5 "`p_public_ctrl_vs_wave2'") ///
       text(20 1 "`perc_control_private'") text(20 2 "`perc_control_public'") text(20 4 "`perc_info_private'") text(20 5 "`perc_info_public'") text(20 7 "`perc_wave2_private'") text(20 8 "`perc_wave2_public'") ///
       xtitle("") ytitle("Donation Rates")
gr_edit legend.DragBy 60 25
graph export "$ExtremeToMainstream_Replication/results/figures/app_figureD1.eps", replace
restore




*** Appendix Experiment 2B

use "$ExtremeToMainstream_Replication/processed/app_exp2b_clean.dta", clear

* Figure E1 Panel A

reg donation_amount control anti_minarets support anti_minarets_anonymous support_anonymous if (treatment != "Anti-Minarets Referendum"), nocons r

foreach i in control anti_minarets support anti_minarets_anonymous support_anonymous {
local dollar_`i' = "$" + string(round(_b[`i'],0.01),"%9.2f")
}

test _b[control]=_b[anti_minarets]
if round(r(p),.0001) > 0.001 local p_anti = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_anti = "p<0.001"
test _b[control]=_b[support]
if round(r(p),.0001) > 0.001 local p_support = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_support = "p<0.001"
test _b[control]=_b[anti_minarets_anonymous]
if round(r(p),.0001) > 0.001 local p_anti_an = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_anti_an = "p<0.001"
test _b[control]=_b[support_anonymous]
if round(r(p),.0001) > 0.001 local p_support_an = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_support_an = "p<0.001"
test _b[anti_minarets]=_b[anti_minarets_anonymous]
if round(r(p),.0001) > 0.001 local p_anti_anti_an = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_anti_anti_an = "p<0.001"
test _b[support]=_b[support_anonymous]
if round(r(p),.0001) > 0.001 local p_support_support_an = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_support_support_an = "p<0.001"
test _b[anti_minarets]=_b[support]
if round(r(p),.0001) > 0.001 local p_anti_support = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_anti_support = "p<0.001"
test _b[anti_minarets_anonymous]=_b[support_anonymous]
if round(r(p),.0001) > 0.001 local p_anti_support_an = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_anti_support_an = "p<0.001"

preserve
keep if (treatment != "Anti-Minarets Referendum")
keep donation_amount group
collapse (mean) meandonate = donation_amount (sd) sddonate=donation_amount (count) n=donation_amount, by(group)
generate hidonate = meandonate + 1.96*(sddonate/sqrt(n))
generate lodonate = meandonate - 1.96*(sddonate/sqrt(n))
generate order = 1 if group == "Control"
replace order = 2 if group == "Anti-Minarets"
replace order = 3 if group == "Anti-Minarets Public Support"
replace order = 4 if group == "Anti-Minarets Anonymous"
replace order = 5 if group == "Anti-Minarets Public Support Anonymous"
twoway (bar meandonate order if (group=="Control" | group == "Anti-Minarets" | group == "Anti-Minarets Public Support" | group == "Anti-Minarets Anonymous" | group == "Anti-Minarets Public Support Anonymous" |), barw(0.5) fc(maroon) fi(inten50) lc(black) lw(medium)) ///
       (pci 1.235 1 1.26 1 	1.26 1 1.26 1.8		1.26 2.2 1.26 3 1.235 3 1.26 3, lc(black)) ///
       (pci 1.135 2.02 1.16 2.02 	1.16 2.02 1.16 2.3		1.16 2.7 1.16 3 	1.135 3 1.16 3, lc(black)) ///
       (pci 1.135 1 1.16 1 	1.16 1 1.16 1.3		1.16 1.7 1.16 1.98 1.135 1.98 1.16 1.98, lc(black)) ///
       (pci 1.135 4 1.16 4 	1.16 4 1.16 4.3		1.16 4.7 1.16 5 1.135 5 1.16 5, lc(black)) ///
       (pci 1.535 1 1.56 1 	1.56 1 1.56 2.3		1.56 2.7 1.56 4 1.535 4 1.56 4, lc(black)) ///
       (pci 1.635 1 1.66 1 	1.66 1 1.66 2.8		1.66 3.2 1.66 5 1.635 5 1.66 5, lc(black)) ///
       (pci 1.435 3 1.46 3 	1.46 3 1.46 3.8		1.46 4.2 1.46 5 1.435 5 1.46 5, lc(black)) ///
       (pci 1.335 2 1.36 2 	1.36 2 1.36 2.8		1.36 3.2 1.36 4 1.335 4 1.36 4, lc(black)) ///
       (rcap hidonate lodonate order, lc(black)), ///
       graphregion(color(white)) ///
       ylabel(0(.25)1.6, nogrid) yscale(range(0 1.6)) ///
       xlabel(1 "Control Group" 2 "Anti-Minarets" 3 `" "Anti-Minarets"	"Public Support" "' 4 `" "Anonymous" "Anti-Minarets" "' 5 `" "Anonymous" "Anti-Minarets"	"Public Support" "', noticks) xtick(1(1)5) ///
       text(1.16 1.5 "`p_anti'", size(small)) text(1.16 2.5 "`p_anti_support'", size(small)) text(1.26 2 "`p_support'", size(small)) ///
       text(1.16 4.5 "`p_anti_support_an'", size(small)) ///
       text(1.56 2.5 "`p_anti_an'", size(small)) ///
       text(1.66 3 "`p_support_an'", size(small)) ///
       text(1.36 3 "`p_anti_anti_an'", size(small)) ///
       text(1.46 4 "`p_support_support_an'", size(small)) ///
       text(0.5 1 "`dollar_control'") text(0.5 2 "`dollar_anti_minarets'") text(0.5 3 "`dollar_support'") text(0.5 4 "`dollar_anti_minarets_anonymous'") text(0.5 5 "`dollar_support_anonymous'") ///
       xtitle("") ytitle("Average Donation Amounts") ///
       legend(off)
graph export "$ExtremeToMainstream_Replication/results/figures/app_figureE1_panelA.eps", replace
restore



* Figure E1 Panel B

reg no_donation control anti_minarets support anti_minarets_anonymous support_anonymous if (treatment != "Anti-Minarets Referendum"), nocons r

foreach i in control anti_minarets support anti_minarets_anonymous support_anonymous {
local perc_`i' = string(round(_b[`i']*100,1),"%9.0f") + "%"
}

test _b[control]=_b[anti_minarets]
if round(r(p),.0001) > 0.001 local p_anti = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_anti = "p<0.001"
test _b[control]=_b[support]
if round(r(p),.0001) > 0.001 local p_support = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_support = "p<0.001"
test _b[control]=_b[anti_minarets_anonymous]
if round(r(p),.0001) > 0.001 local p_anti_an = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_anti_an = "p<0.001"
test _b[control]=_b[support_anonymous]
if round(r(p),.0001) > 0.001 local p_support_an = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_support_an = "p<0.001"
test _b[anti_minarets]=_b[anti_minarets_anonymous]
if round(r(p),.0001) > 0.001 local p_anti_anti_an = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_anti_anti_an = "p<0.001"
test _b[support]=_b[support_anonymous]
if round(r(p),.0001) > 0.001 local p_support_support_an = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_support_support_an = "p<0.001"
test _b[anti_minarets]=_b[support]
if round(r(p),.0001) > 0.001 local p_anti_support = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_anti_support = "p<0.001"
test _b[anti_minarets_anonymous]=_b[support_anonymous]
if round(r(p),.0001) > 0.001 local p_anti_support_an = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_anti_support_an = "p<0.001"

preserve
keep if (treatment != "Anti-Minarets Referendum")
keep no_donation group
collapse (mean) meandonate = no_donation (sd) sddonate=no_donation (count) n=no_donation, by(group)
generate hidonate = meandonate + 1.96*(sddonate/sqrt(n))
generate lodonate = meandonate - 1.96*(sddonate/sqrt(n))
generate order = 1 if group == "Control"
replace order = 2 if group == "Anti-Minarets"
replace order = 3 if group == "Anti-Minarets Public Support"
replace order = 4 if group == "Anti-Minarets Anonymous"
replace order = 5 if group == "Anti-Minarets Public Support Anonymous"
twoway (bar meandonate order if (group=="Control" | group == "Anti-Minarets" | group == "Anti-Minarets Public Support" | group == "Anti-Minarets Anonymous" | group == "Anti-Minarets Public Support Anonymous" |), barw(0.5) fc(maroon) fi(inten50) lc(black) lw(medium)) ///
       (pci 0.58 1 0.59 1 	0.59 1 0.59 1.8		0.59 2.2 0.59 3 0.58 3 0.59 3, lc(black)) ///
       (pci 0.53 2.02 0.54 2.02 	0.54 2.02 0.54 2.3		0.54 2.7 0.54 3 	0.53 3 0.54 3, lc(black)) ///
       (pci 0.53 1 0.54 1 	0.54 1 0.54 1.3		0.54 1.7 0.54 1.98 0.53 1.98 0.54 1.98, lc(black)) ///
       (pci 0.53 4 0.54 4 	0.54 4 0.54 4.3		0.54 4.7 0.54 5 0.53 5 0.54 5, lc(black)) ///
       (pci 0.73 1 0.74 1 	0.74 1 0.74 2.3		0.74 2.7 0.74 4 0.73 4 0.74 4, lc(black)) ///
       (pci 0.78 1 0.79 1 	0.79 1 0.79 2.8		0.79 3.2 0.79 5 0.78 5 0.79 5, lc(black)) ///
       (pci 0.68 3 0.69 3 	0.69 3 0.69 3.8		0.69 4.2 0.69 5 0.68 5 0.69 5, lc(black)) ///
       (pci 0.63 2 0.64 2 	0.64 2 0.64 2.8		0.64 3.2 0.64 4 0.63 4 0.64 4, lc(black)) ///
       (rcap hidonate lodonate order, lc(black)), ///
       graphregion(color(white)) ///
       ylabel(0(.1)0.75, nogrid) yscale(range(0 0.7)) ///
       xlabel(1 "Control Group" 2 "Anti-Minarets" 3 `" "Anti-Minarets"	"Public Support" "' 4 `" "Anonymous" "Anti-Minarets" "' 5 `" "Anonymous" "Anti-Minarets"	"Public Support" "', noticks) xtick(1(1)5) ///
       text(0.54 1.5 "`p_anti'", size(small)) text(0.54 2.5 "`p_anti_support'", size(small)) text(0.59 2 "`p_support'", size(small)) ///
       text(0.54 4.5 "`p_anti_support_an'", size(small)) ///
       text(0.74 2.5 "`p_anti_an'", size(small)) ///
       text(0.79 3 "`p_support_an'", size(small)) ///
       text(0.64 3 "`p_anti_anti_an'", size(small)) ///
       text(0.69 4 "`p_support_support_an'", size(small)) ///
       text(0.125 1 "`perc_control'") text(0.125 2 "`perc_anti_minarets'") text(0.125 3 "`perc_support'")  text(0.125 4 "`perc_anti_minarets_anonymous'") text(0.125 5 "`perc_support_anonymous'") ///
       xtitle("") ytitle("Share Not Donating") ///
       legend(off)
graph export "$ExtremeToMainstream_Replication/results/figures/app_figureE1_panelB.eps", replace
restore




*** Appendix Experiment 3

use "$ExtremeToMainstream_Replication/processed/app_exp3_clean.dta", clear

* Appendix Figure F1

reg donate control_private control_public support_private support_public const_private const_public, nocons r

foreach i in control_private control_public support_private support_public const_private const_public {
local perc_`i' = string(round(_b[`i']*100,1),"%9.0f") + "%"
}

test _b[control_private]=_b[control_public]
if round(r(p),.0001) > 0.001 local p_control_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_control_pv_vs_pb = "p<0.001"
test _b[support_private]=_b[support_public]
if round(r(p),.0001) > 0.001 local p_support_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_support_pv_vs_pb = "p<0.001"
test _b[const_private]=_b[const_public]
if round(r(p),.0001) > 0.001 local p_const_pv_vs_pb = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_const_pv_vs_pb = "p<0.001"
test _b[control_private] = _b[const_private]
if round(r(p),.0001) > 0.001 local p_private_ctrl_vs_const = "p=" + string(round(r(p),.001),"%9.3f")
if round(r(p),.0001) < 0.001 local p_private_ctrl_vs_const = "p<0.001"

display _N
preserve
keep donate treatment
replace donate = donate * 100
collapse (mean) meandonate = donate (sd) sddonate=donate (count) n=donate, by(treatment)
generate hidonate = meandonate + 1.96*(sddonate/sqrt(n))
generate lodonate = meandonate - 1.96*(sddonate/sqrt(n))
generate order = 1 if treatment == "Control Private"
replace order = 2 if treatment == "Control Public"
replace order = 4 if treatment == "Public Support Information Private"
replace order = 5 if treatment == "Public Support Information Public"
replace order = 7 if treatment == "Unconstitutionality Information Private"
replace order = 8 if treatment == "Unconstitutionality Information Public"
twoway (bar meandonate order if (treatment == "Control Private" | treatment == "Public Support Information Private" | treatment == "Unconstitutionality Information Private"), barw(0.8) fc(white) lc(black) lw(medium)) ///
       (bar meandonate order if (treatment == "Control Public" | treatment == "Public Support Information Public" | treatment == "Unconstitutionality Information Public"), barw(0.8) fc(maroon) fi(inten50) lc(black) lw(medium)) ///
       (pci 52.5 1 52.5 1.05  51.5 1 52.5 1  52.5 2 52.5 1.95  51.5 2 52.5 2, lc(black)) ///
       (pci 52.5 4 52.5 4.05  51.5 4 52.5 4  52.5 5 52.5 4.95  51.5 5 52.5 5, lc(black)) ///
       (pci 52.5 7 52.5 7.05  51.5 7 52.5 7  52.5 8 52.5 7.95  51.5 8 52.5 8, lc(black)) ///
       (pci 57.5 1 57.5 3.55  56.5 1 57.5 1  57.5 7 57.5 4.45  56.5 7 57.5 7, lc(black)) ///      
       (rcap hidonate lodonate order, lc(black)), ///
       graphregion(color(white)) ///
       legend(row(2) order(1 "Private" 2 "Public") region(lstyle(none)) ring(0) symxsize(4)) ///
       ylabel(0(10)50, nogrid) yscale(range(0 57.5)) ///
       xlabel( 1.5 "Control treatment" 4.5 `" "Public Support" "Public Support Information" "' 7.5 `""Unconstitutionality" "Public Support Information" "', noticks) xtick(3(3)6) ///
       text(52.5 1.5 "`p_control_pv_vs_pb'") text(52.5 4.5 "`p_support_pv_vs_pb'") text(52.5 7.5 "`p_const_pv_vs_pb'") ///
       text(57.5 4 "`p_private_ctrl_vs_const'") ///
       text(15 1 "`perc_control_private'") text(15 2 "`perc_control_public'") text(15 4 "`perc_support_private'") text(15 5 "`perc_support_public'") text(15 7 "`perc_const_private'") text(15 8 "`perc_const_public'") ///
       xtitle("") ytitle("Donation Rates")
gr_edit legend.DragBy 60 25
graph export "$ExtremeToMainstream_Replication/results/figures/app_figureF1.eps", replace
restore


** EOF
